@@ -306,6 +306,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateReplicationInstance(self, request):
+        """创建从实例
+
+        :param request: Request instance for CreateReplicationInstance.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.CreateReplicationInstanceRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.CreateReplicationInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateReplicationInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateReplicationInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateRepository(self, request):
         """用于企业版创建镜像仓库
 
@@ -362,6 +390,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateSecurityPolicy(self, request):
+        """创建实例公网访问白名单策略
+
+        :param request: Request instance for CreateSecurityPolicy.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.CreateSecurityPolicyRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.CreateSecurityPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateSecurityPolicy", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateSecurityPolicyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateUserPersonal(self, request):
         """创建个人用户
 
@@ -754,6 +810,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteSecurityPolicy(self, request):
+        """删除实例公网访问白名单策略
+
+        :param request: Request instance for DeleteSecurityPolicy.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.DeleteSecurityPolicyRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.DeleteSecurityPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteSecurityPolicy", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteSecurityPolicyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteWebhookTrigger(self, request):
         """删除触发器
 
@@ -1426,6 +1510,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSecurityPolicies(self, request):
+        """查询实例公网访问白名单策略
+
+        :param request: Request instance for DescribeSecurityPolicies.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.DescribeSecurityPoliciesRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.DescribeSecurityPoliciesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSecurityPolicies", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSecurityPoliciesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserQuotaPersonal(self, request):
         """查询个人用户配额
 
@@ -1622,6 +1734,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ManageReplication(self, request):
+        """管理实例同步
+
+        :param request: Request instance for ManageReplication.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.ManageReplicationRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.ManageReplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ManageReplication", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ManageReplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyApplicationTriggerPersonal(self, request):
         """用于修改应用更新触发器
 
@@ -1790,6 +1930,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifySecurityPolicy(self, request):
+        """更新实例公网访问白名单
+
+        :param request: Request instance for ModifySecurityPolicy.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.ModifySecurityPolicyRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.ModifySecurityPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifySecurityPolicy", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifySecurityPolicyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyUserPasswordPersonal(self, request):
         """修改个人用户登录密码
 
